<?php	
require_once( 'core.php' );

$t_core_path = config_get( 'core_path' );

require_once( $t_core_path . 'compress_api.php' );
require_once( $t_core_path . 'filter_api.php' );
require_once( $t_core_path . 'last_visited_api.php' );

auth_ensure_user_authenticated();


if(current_user_get_access_level() < 55) {
	echo '<h1>Access denied</h1>';
	return;	
}

if(isset($_GET['ids'])) {
	$where = 'WHERE `mantis_bug_table`.`id` IN (' . $_GET['ids'] . ')';	
} else {
	$where = 'WHERE `mantis_bug_table`.`status` < 90';
}

if(isset($_GET['project_id'])) {
	$where .= ' AND `mantis_bug_table`.`project_id` = ' . $_GET['project_id'];
}

$sql = 'SELECT 					
			DATE_FORMAT(`mantis_bug_table`.`last_updated`, "%b %d") as `date`,
			DATE_FORMAT(`mantis_bug_table`.`last_updated`, "%w") as `day_of_week`,
			`mantis_bug_table`.`summary`,  
			`mantis_bug_table`.`category_id`,
			`mantis_bug_table`.`priority`,
			`mantis_bug_table`.`status`,  
			`mantis_bug_table`.`id`,
			`mantis_user_table`.`username`,
			`mantis_bug_text_table`.`description`,
			`mantis_bug_text_table`.`additional_information`
		FROM `mantis_bug_table`
		LEFT JOIN `mantis_user_table` ON `mantis_user_table`.`id` = `mantis_bug_table`.`handler_id`
		LEFT JOIN `mantis_bug_text_table` ON `mantis_bug_table`.`bug_text_id` = `mantis_bug_text_table`.`id` ' . $where . ' 
		ORDER BY `priority` DESC';
		
		
$result = db_query($sql);
$row_count = db_num_rows( $result );

function getStatus($id) {
	switch($id) {
		case 20:
			return 'feedback';
		case 50:
			return 'assigned';
		case 80:
			return 'resolved';
		case 90:
			return 'closed';
		default:
			return 'other';			
	}
}

function renderPriority($priority) {
	return str_repeat('*', round($priority / 10));
}

$board = array();
$columns = array(
	50 => 'Assigned',
	30 => 'In progress',
	80 => 'Resolved',
	40 => 'Confirmed',	
);
$knownStatuses = array_keys($columns);
?>
<html>
<style>
body {
	font-size:12px;
	font-family: Arial;
}
.sticker {
	/*border:1px solid red;*/
	background-color: #FFF8C4;
	margin:5px 0px 10px 0px;
	padding:10px;	
	font-size:12px;
}
.sticker h3{
	font-size:15px;	
	padding:0px;
	margin:0px 0px 5px 0px;	
}
.sticker h3 a {
	color: #007ED8;	
}
#board tr td {
	border-bottom: 1px solid #eeeeee;
}
#board th {
	padding:10px;
}
.dev {
	text-align:center;	
}
</style>
<body>
<?

//echo '<table>';
for ( $i=0 ; $i < $row_count ; $i++ ) {
	$row = db_fetch_array( $result );
	
	if(!in_array($row['status'], $knownStatuses)) {		
		$row['status'] = 50;
	}
	
	if(!isset($board[$row['username']])) {
		$board[$row['username']] = array();
	}
	
	if(!isset($board[$row['username']][$row['status']])) {
		$board[$row['username']][$row['status']] = array();
	}	
	
	$board[$row['username']][$row['status']][] = array(
		'id' => $row['id'],
		'summary' => $row['summary'],
		//'description' => $row['description']
	);
	/*
	echo '<pre>';
	var_dump($row);
	echo '</pre>';
	*/
	//echo '<tr><td width="100"><h1>' . $row['id'] . '<sup>' . renderPriority($row['priority']) . '</sup></h1></td><td><h3>' . nl2br($row['summary']) . '</h3></td></tr>';
	//echo '<tr><td style="border-bottom:1px solid #aaaaaa;" colspan="2">' . nl2br($row['description']) . '<br><br><br><br><br><br><br><br><br></td></tr>';	
	//var_dump($row);
}
//echo '</table>';

echo '<table id="board" border="0" width="100%"><tr><th width="20%">Developer</th>';
foreach($columns as $status => $title) {
	echo '<th width="20%" bgcolor="' . get_status_color($status) . '">' . $title . '</th>';	
}
echo '</tr>';

foreach($board as $developer => $data) {
	echo '<tr><td class="dev">' . (empty($developer) ? 'nobody' : $developer) . '</td>';
	foreach($columns as $status => $title) {
		echo '<td>';
		if(is_array($data[$status])) {
			foreach($data[$status] as $task) {
				echo '<div class="sticker"><h3><a href="view.php?id=' . $task['id'] . '">' . $task['id'] . '</a></h3>' . $task['summary'] . '</div>';
			}
		} else {
			echo '&nbsp;';
		}
		/*
		echo '<pre>';
		var_dump($data[$status]);
		echo '</pre></td>';
		*/
	}
	echo '</tr>';
}
echo '</table>';
/*
echo '<pre>';
var_dump($board);
echo '</pre>';
*/
exit();
?>
</body>
</html>
